@@ -4,7 +4,7 @@ from urllib3.util.retry import Retry
 exponential_backoff_retry = Retry(
     total=3,
     status_forcelist=[429, 500, 502, 503, 504],
-    method_whitelist=["GET", "POST"],
+    allowed_methods=["GET", "POST"],
     backoff_factor=1,
 )
 
